import { useState } from "react";

const DisconnectButton = ({ onDelete, disabled = false }) => {
    const [isOpen, setIsOpen] = useState(false);

    const openModal = () => {
        setIsOpen(true);
    };

    const closeModal = () => {
        setIsOpen(false);
    };

    return (
        <>
            {/* Botão de exclusão */}
            <button className="bg-danger opacity-80 h-8 flex justify-center items-center text-white p-2 rounded-md hover:opacity-100 text-[.7rem] font-semibold"
                onClick={() => openModal()}>
                Desconectar
            </button>

            {/* Modal */}
            {isOpen && (
                <div className="fixed inset-0 flex items-center justify-center bg-background-primary bg-opacity-60 backdrop-blur-sm z-[9999]">
                    <div className="bg-danger p-4 rounded-2xl w-96">
                        <div className="flex justify-start items-center">
                            <i className="bi bi-exclamation-circle text-4xl text-text-white animate-pulse"></i>
                            <div className="ms-3">
                                <h2 className="text-lg font-semibold text-text-white">Desconectar Instância</h2>
                                <p className="text-sm text-text-white mt-1">Tem certeza que deseja Desconectar essa Instância?</p>
                            </div>
                        </div>

                        <div className="mt-4 flex justify-end space-x-3">
                            <button className="text-sm" onClick={closeModal}>
                                Cancelar
                            </button>
                            <button className={`border border-text-white border-opacity-50 px-3 py-2 rounded hover:border-opacity-100 text-sm ${disabled && 'opacity-80 cursor-not-allowed'}`} onClick={onDelete} disabled={disabled}>
                                <div className="flex">
                                    {disabled ? (
                                        <>
                                            <svg className="mr-3 h-5 w-5 animate-spin text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                                                <circle className="opacity-35" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
                                                <path className="opacity-85" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                                            </svg>
                                            Desconectando
                                        </>
                                    ) : ('Desconectar')
                                    }
                                </div>
                            </button>
                        </div>
                    </div>
                </div>
            )}
        </>
    );
};

export default DisconnectButton;
